#!/usr/bin/env python
# -*- coding: utf-8 -*-
from .ctt import get_package_status

"""
    __init__.py
    ~~~~~~~~~~~

    Interface to CTT ( Portuguese Postal Service )

    :copyright: (c) 2017 by Bruno Martins.
    :license: see LICENSE for more details.
"""

__title__ = 'ctt'
__version__ = '0.0.1'
__author__ = 'Bruno Martins'
